"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const orgSelector = require("../../../../shared/selectors/organizationSelector");
const syUserService = require("../../../../shared/syUsrService");
const orgValidator = require("../../../../shared/validations/orgValidations");
// Initialize Messages with the current plugin directory
command_1.core.Messages.importMessagesDirectory(__dirname);
// Load the specific messages for this file. Messages from @salesforce/command, @salesforce/core,
// or any library that is using the messages framework can also be loaded this way.
const messages = command_1.core.Messages.loadMessages('rstk-sfdx-plugins-for-carmax', 'production');
class Scratch extends command_1.SfdxCommand {
    async run() {
        this.ux.startSpinner(messages.getMessage('commandSpinner'));
        const orgQueryResult = await orgSelector.select(this.org.getConnection());
        if (orgQueryResult.totalSize <= 0) {
            throw new Error('FATAL error -- No records returned for Organization query');
        }
        this.ux.startSpinner('Activating the org');
        // this.org is guaranteed because requiresUsername=true, as opposed to supportsUsername
        const conn = this.org.getConnection();
        const validatorResponse = await orgValidator.isProductionOrg(this.org);
        // this.ux.log('validatorResponse == ' + validatorResponse );
        if (!validatorResponse) {
            // this command can only be run on a production org
            throw new command_1.core.SfdxError(messages.getMessage('errorExecutionNotAllowed', [this.org.getOrgId()]));
        }
        // Setup the "Automated Process" user used by platform events in the SYUSR SObject
        try {
            await syUserService.setupAutomatedProcessUser(conn);
        }
        catch (e) {
            // the automated process user is already setup in this org.  Do nothing.
            this.logger.debug('The Automated Process user is already setup in this org.');
        }
        this.ux.stopSpinner();
        this.ux.log(messages.getMessage('commandSuccess', [this.org.getOrgId()]));
        return;
    }
}
Scratch.description = messages.getMessage('commandDescription');
Scratch.examples = [
    `$ sfdx rstk:activate:org:sandbox --targetusername myOrg@example.com --targetdevhubusername devhub@org.com
        Rootstock ERP package has been successfully activated for sandbox org myOrg@example.com.
        `
];
Scratch.flagsConfig = {
// flag with a value (-n, --name=VALUE)
};
// Comment this out if your command does not require an org username
Scratch.requiresUsername = true;
// Comment this out if your command does not support a hub org username
Scratch.supportsDevhubUsername = true;
// Set this to true if your command requires a project workspace; 'requiresProject' is false by default
Scratch.requiresProject = false;
exports.default = Scratch;
//# sourceMappingURL=production.js.map