"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const rstkSyUsrType = require("../types/rstk_syusr");
const rslabgrdsSelector = require("./selectors/rstk__rtlabgrdsSelector");
const syCmpsSelector = require("./selectors/rstk__sycmpsSelector");
const syDivsSelector = require("./selectors/rstk__sydivsSelector");
const syUsrsSelector = require("./selectors/rstk__syusrsSelector");
const usersSelector = require("./selectors/usersSelector");
async function setupSYUSREntryForUser(userToConfigure, company, division, externalId, seedSyUser, conn) {
    // Does this userToConfigure already have a SYUSR record?
    const syusrQueryResult = await syUsrsSelector.selectByUser(userToConfigure, conn);
    // console.log('syusrQueryResult.done == ' + syusrQueryResult.done);
    // console.log('syusrQueryResult.totalSize == ' + syusrQueryResult.totalSize);
    if (syusrQueryResult.totalSize > 0) {
        // the record already exists.  Exit this method
        throw new Error('rstk__syusr__c record already present for User ' + userToConfigure.Id);
    }
    // No previous SYUSR record was found.
    // Create a new SYUSR record with info from userToConfigure
    let syUsr = {};
    if (seedSyUser != null) {
        syUsr = seedSyUser;
    }
    syUsr.rstk__syusr_empl_email__c = userToConfigure.Email;
    syUsr.rstk__syusr_employee__c = userToConfigure.Id;
    syUsr.Name = userToConfigure.Name;
    syUsr.rstk__searchindex__c = userToConfigure.Name;
    if (externalId != null) {
        syUsr.rstk__externalid__c = externalId;
        syUsr.rstk__syusr_clockno__c = +externalId;
        syUsr.rstk__syusr_usrno__c = +externalId;
    }
    syUsr.rstk__syusr_dfltcmpno__c = company.Id; // default company
    syUsr.rstk__syusr_lastcmpno__c = company.Id; // last company
    syUsr.rstk__syusr_dfltdiv__c = division.Id; // default division
    syUsr.rstk__syusr_lastdiv__c = division.Id;
    syUsr.rstk__syusr_lastsalesdiv__c = division.Id;
    syUsr.rstk__syusr_salesdiv__c = division.Id;
    // syUsr.rstk__syusr_lastsite__c = '';
    syUsr.rstk__syusr_licreq__c = true;
    const labgrdQueryResult = await rslabgrdsSelector.selectByExternalId(division.rstk__externalid__c + '_DFLT', conn);
    syUsr.rstk__syusr_labgrd__c = labgrdQueryResult.records[0].Id; // last div concatentated with DFLT
    syUsr.rstk__triggeroptions__c = '{"ST":"1","SAE":"1"}';
    await conn.insert(rstkSyUsrType.sobjectType(), syUsr);
    // console.log( await conn.insert( rstkSyUsrType.sobjectType(), syUsr ) );
}
exports.setupSYUSREntryForUser = setupSYUSREntryForUser;
async function setupAutomatedProcessUser(conn) {
    // find the automated process user for this org
    const automatedProcessUserQueryResult = await usersSelector.selectAutomatedProcessUser(conn);
    const automatedProcessUser = automatedProcessUserQueryResult.records[0];
    automatedProcessUser.Email = automatedProcessUser.Email + '.com';
    // find the default rstk company
    const companyQueryResult = await syCmpsSelector.selectDefault(conn);
    const company = companyQueryResult.records[0];
    // find the default rstk division in that company
    const divisionQueryResult = await syDivsSelector.selectByCompany(company, conn);
    const division = divisionQueryResult.records[0];
    const externalId = '9999998';
    const syUsr = {};
    syUsr.rstk__syusr_multicompany__c = true;
    syUsr.rstk__syusr_multidiv__c = true;
    // setup that user in the SYUSR table
    setupSYUSREntryForUser(automatedProcessUser, company, division, externalId, syUsr, conn);
}
exports.setupAutomatedProcessUser = setupAutomatedProcessUser;
async function setupDXScratchOrgDefaultUser(conn) {
    const currentUserQueryResult = await usersSelector.selectByUsername(conn.getUsername(), conn);
    // find the default rstk company
    const companyQueryResult = await syCmpsSelector.selectDefault(conn);
    const company = companyQueryResult.records[0];
    // find the default rstk division in that company
    const divisionQueryResult = await syDivsSelector.selectByCompany(company, conn);
    const division = divisionQueryResult.records[0];
    const externalId = '9999997';
    // setup that user in the SYUSR table
    setupSYUSREntryForUser(currentUserQueryResult.records[0], company, division, externalId, null, conn);
}
exports.setupDXScratchOrgDefaultUser = setupDXScratchOrgDefaultUser;
//# sourceMappingURL=syUsrService.js.map